@@ -515,16 +515,16 @@ def column_to_bool(col_):
 def result_set_to_rows(
     result_set: List[Any], result_meta: Optional[List[ResultMetadata]] = None
 ) -> List[Row]:
-    if result_meta:
-        col_names = [col.name for col in result_meta]
-        rows = []
-        for data in result_set:
-            row = Row(*data)
-            # row might have duplicated column names
+    col_names = [col.name for col in result_meta] if result_meta else None
+    rows = []
+    for data in result_set:
+        if data is None:
+            raise ValueError("Result returned from Python connector is None")
+        row = Row(*data)
+        # row might have duplicated column names
+        if col_names:
             row._fields = col_names
-            rows.append(row)
-    else:
-        rows = [Row(*row) for row in result_set]
+        rows.append(row)
     return rows
 
 
@@ -533,6 +533,8 @@ def result_set_to_iter(
 ) -> Iterator[Row]:
     col_names = [col.name for col in result_meta] if result_meta else None
     for data in result_set:
+        if data is None:
+            raise ValueError("Result returned from Python connector is None")
         row = Row(*data)
         if col_names:
             row._fields = col_names
