@@ -22,7 +22,6 @@ from snowflake.snowpark._internal.analyzer.table_merge_expression import (
 from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
 from snowflake.snowpark._internal.telemetry import add_api_call, set_api_call_source
 from snowflake.snowpark._internal.type_utils import ColumnOrLiteral
-from snowflake.snowpark._internal.utils import warning
 from snowflake.snowpark.column import Column
 from snowflake.snowpark.dataframe import DataFrame, _disambiguate
 from snowflake.snowpark.row import Row
@@ -83,15 +82,15 @@ class WhenMatchedClause:
             >>> # if its key is equal to the key of any row in target.
             >>> # For all such rows, update its value to the value of the
             >>> # corresponding row in source.
-            >>> from snowflake.snowpark.functions import when_matched
+            >>> from snowflake.snowpark.functions import when_matched, lit
             >>> target_df = session.create_dataframe([(10, "old"), (10, "too_old"), (11, "old")], schema=["key", "value"])
             >>> target_df.write.save_as_table("my_table", mode="overwrite", table_type="temporary")
             >>> target = session.table("my_table")
             >>> source = session.create_dataframe([(10, "new")], schema=["key", "value"])
-            >>> target.merge(source, target["key"] == source["key"], [when_matched().update({"value": source["value"]})])
-            MergeResult(rows_inserted=0, rows_updated=2, rows_deleted=0)
+            >>> target.merge(source, (target["key"] == source["key"]) & (target["value"] == lit("too_old")), [when_matched().update({"value": source["value"]})])
+            MergeResult(rows_inserted=0, rows_updated=1, rows_deleted=0)
             >>> target.collect() # the value in the table is updated
-            [Row(KEY=10, VALUE='new'), Row(KEY=10, VALUE='new'), Row(KEY=11, VALUE='old')]
+            [Row(KEY=10, VALUE='old'), Row(KEY=10, VALUE='new'), Row(KEY=11, VALUE='old')]
 
         Note:
             An exception will be raised if this method or :meth:`WhenMatchedClause.delete`
@@ -259,6 +258,7 @@ class Table(DataFrame):
         super().__init__(
             session, session._analyzer.resolve(UnresolvedRelation(table_name))
         )
+        self.is_cached: bool = self.is_cached  #: Whether the table is cached.
         self.table_name: str = table_name  #: The table name
 
         if self._session.sql_simplifier_enabled:
@@ -340,7 +340,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = True,
     ) -> UpdateResult:
-        ...
+        ...  # pragma: no cover
 
     @overload
     def update(
@@ -352,7 +352,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = False,
     ) -> "snowflake.snowpark.AsyncJob":
-        ...
+        ...  # pragma: no cover
 
     def update(
         self,
@@ -377,7 +377,7 @@ class Table(DataFrame):
             source: An optional :class:`DataFrame` that is included in ``condition``.
                 It can also be another :class:`Table`.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
-            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+            block: A bool value indicating whether this function will wait until the result is available.
                 When it is ``False``, this function executes the underlying queries of the dataframe
                 asynchronously and returns an :class:`AsyncJob`.
 
@@ -410,12 +410,6 @@ class Table(DataFrame):
             >>> t.collect()
             [Row(A=1, B=0), Row(A=1, B=0), Row(A=2, B=0), Row(A=2, B=0), Row(A=3, B=0), Row(A=3, B=0)]
         """
-        if not block:
-            warning(
-                "update.block",
-                "block argument is experimental. Do not use it in production.",
-            )
-
         if source:
             assert (
                 condition is not None
@@ -451,7 +445,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = True,
     ) -> DeleteResult:
-        ...
+        ...  # pragma: no cover
 
     @overload
     def delete(
@@ -462,7 +456,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = False,
     ) -> "snowflake.snowpark.AsyncJob":
-        ...
+        ...  # pragma: no cover
 
     def delete(
         self,
@@ -482,7 +476,7 @@ class Table(DataFrame):
             source: An optional :class:`DataFrame` that is included in ``condition``.
                 It can also be another :class:`Table`.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
-            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+            block: A bool value indicating whether this function will wait until the result is available.
                 When it is ``False``, this function executes the underlying queries of the dataframe
                 asynchronously and returns an :class:`AsyncJob`.
 
@@ -514,12 +508,6 @@ class Table(DataFrame):
             >>> t.collect()
             [Row(A=1, B=1), Row(A=1, B=2)]
         """
-        if not block:
-            warning(
-                "delete.block",
-                "block argument is experimental. Do not use it in production.",
-            )
-
         if source:
             assert (
                 condition is not None
@@ -552,7 +540,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = True,
     ) -> MergeResult:
-        ...
+        ...  # pragma: no cover
 
     @overload
     def merge(
@@ -564,7 +552,7 @@ class Table(DataFrame):
         statement_params: Optional[Dict[str, str]] = None,
         block: bool = False,
     ) -> "snowflake.snowpark.AsyncJob":
-        ...
+        ...  # pragma: no cover
 
     def merge(
         self,
@@ -594,7 +582,7 @@ class Table(DataFrame):
                 of :class:`WhenMatchedClause` and :class:`WhenNotMatchedClause`, and will
                 be performed sequentially in this list.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
-            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+            block: A bool value indicating whether this function will wait until the result is available.
                 When it is ``False``, this function executes the underlying queries of the dataframe
                 asynchronously and returns an :class:`AsyncJob`.
 
@@ -611,12 +599,6 @@ class Table(DataFrame):
             >>> target.collect()
             [Row(KEY=13, VALUE=None), Row(KEY=12, VALUE=None), Row(KEY=10, VALUE='new'), Row(KEY=10, VALUE='new'), Row(KEY=11, VALUE='old')]
         """
-        if not block:
-            warning(
-                "merge.block",
-                "block argument is experimental. Do not use it in production.",
-            )
-
         inserted, updated, deleted = False, False, False
         merge_exprs = []
         for c in clauses:
