@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
-"""User-defined table functions (UDTFs) in Snowpark."""
+"""User-defined table functions (UDTFs) in Snowpark. Refer to :class:`~snowflake.snowpark.udtf.UDTFRegistration` for details and sample code."""
 import collections.abc
 import sys
 from types import ModuleType
@@ -24,7 +24,6 @@ import snowflake.snowpark
 from snowflake.connector import ProgrammingError
 from snowflake.snowpark._internal import type_utils
 from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
-from snowflake.snowpark._internal.telemetry import TelemetryField
 from snowflake.snowpark._internal.type_utils import (
     ColumnOrName,
     python_type_str_to_object,
@@ -324,6 +323,8 @@ class UDTFRegistration:
         packages: Optional[List[Union[str, ModuleType]]] = None,
         replace: bool = False,
         parallel: int = 4,
+        strict: bool = False,
+        secure: bool = False,
         *,
         statement_params: Optional[Dict[str, str]] = None,
     ) -> UserDefinedTableFunction:
@@ -375,6 +376,11 @@ class UDTFRegistration:
                 command. The default value is 4 and supported values are from 1 to 99.
                 Increasing the number of threads can improve performance when uploading
                 large UDTF files.
+            strict: Whether the created UDTF is strict. A strict UDTF will not invoke the UDTF if any input is
+                null. Instead, a null value will always be returned for that row. Note that the UDTF might
+                still return null for non-null inputs.
+            secure: Whether the created UDTF is secure. For more information about secure functions,
+                see `Secure UDFs <https://docs.snowflake.com/en/sql-reference/udf-secure.html>`_.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
 
         See Also:
@@ -402,6 +408,8 @@ class UDTFRegistration:
             packages,
             replace,
             parallel,
+            strict,
+            secure,
             statement_params=statement_params,
             api_call_source="UDTFRegistration.register",
         )
@@ -419,6 +427,8 @@ class UDTFRegistration:
         packages: Optional[List[Union[str, ModuleType]]] = None,
         replace: bool = False,
         parallel: int = 4,
+        strict: bool = False,
+        secure: bool = False,
         *,
         statement_params: Optional[Dict[str, str]] = None,
     ) -> UserDefinedTableFunction:
@@ -476,6 +486,11 @@ class UDTFRegistration:
                 command. The default value is 4 and supported values are from 1 to 99.
                 Increasing the number of threads can improve performance when uploading
                 large UDTF files.
+            strict: Whether the created UDTF is strict. A strict UDTF will not invoke the UDTF if any input is
+                null. Instead, a null value will always be returned for that row. Note that the UDTF might
+                still return null for non-null inputs.
+            secure: Whether the created UDTF is secure. For more information about secure functions,
+                see `Secure UDFs <https://docs.snowflake.com/en/sql-reference/udf-secure.html>`_.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
 
         Note::
@@ -504,6 +519,8 @@ class UDTFRegistration:
             packages,
             replace,
             parallel,
+            strict,
+            secure,
             statement_params=statement_params,
             api_call_source="UDTFRegistration.register_from_file",
         )
@@ -519,6 +536,8 @@ class UDTFRegistration:
         packages: Optional[List[Union[str, ModuleType]]] = None,
         replace: bool = False,
         parallel: int = 4,
+        strict: bool = False,
+        secure: bool = False,
         *,
         statement_params: Optional[Dict[str, str]] = None,
         api_call_source: str,
@@ -645,6 +664,8 @@ class UDTFRegistration:
                 replace=replace,
                 inline_python_code=code,
                 api_call_source=api_call_source,
+                strict=strict,
+                secure=secure,
             )
         # an exception might happen during registering a udtf
         # (e.g., a dependency might not be found on the stage),
